@@ -8,7 +8,6 @@ import zipfile
 
 from django.core.files.base import ContentFile
 from django.core.files.storage import default_storage
-from django.db.models import Q
 from django.template import Context, Template
 from django.utils import timezone
 from django.utils.module_loading import import_string
@@ -19,21 +18,8 @@ from six import string_types
 from web_fragments.fragment import Fragment
 from xblock.core import XBlock
 from xblock.completable import CompletableXBlockMixin
-from xblock.exceptions import JsonHandlerError
 from xblock.fields import Scope, String, Float, Boolean, Dict, DateTime, Integer
 
-try:
-    try:
-        from common.djangoapps.student.models import CourseEnrollment
-    except RuntimeError:
-        # Older Open edX releases have a different import path
-        from student.models import CourseEnrollment
-    from lms.djangoapps.courseware.models import StudentModule
-except ImportError:
-    CourseEnrollment = None
-    StudentModule = None
-
-
 # Make '_' a no-op so we can scrape strings
 def _(text):
     return text
@@ -94,15 +80,9 @@ class ScormXBlock(XBlock, CompletableXBlockMixin):
     package_meta = Dict(scope=Scope.content)
     scorm_version = String(default="SCORM_12", scope=Scope.settings)
 
-    # lesson_status is for SCORM 1.2 and can take the following values:
-    # "passed", "completed", "failed", "incomplete", "browsed", "not attempted"
-    # In SCORM_2004, status is broken down in two elements:
-    # - cmi.completion_status: "completed" vs "incomplete"
-    # - cmi.success_status: "passed" vs "failed"
-    # We denormalize these two elements by storing the completion status in self.lesson_status.
+    # save completion_status for SCORM_2004
     lesson_status = String(scope=Scope.user_state, default="not attempted")
     success_status = String(scope=Scope.user_state, default="unknown")
-
     lesson_score = Float(scope=Scope.user_state, default=0)
     weight = Float(
         default=1,
@@ -142,16 +122,6 @@ class ScormXBlock(XBlock, CompletableXBlockMixin):
         default=False,
         scope=Scope.settings,
     )
-    popup_on_launch = Boolean(
-        display_name=_("Launch in pop-up window"),
-        help=_(
-            "Launch in pop-up window instead of embedding the SCORM content in "
-            "an iframe. Enable this for older packages that need to be run in "
-            "separate window."
-        ),
-        default=False,
-        scope=Scope.settings,
-    )
 
     has_author_view = True
 
@@ -172,33 +142,25 @@ class ScormXBlock(XBlock, CompletableXBlockMixin):
             context[
                 "message"
             ] = "Click 'Edit' to modify this module and upload a new SCORM package."
-        context["can_view_student_reports"] = True
         return self.student_view(context=context)
 
     def student_view(self, context=None):
         student_context = {
             "index_page_url": self.index_page_url,
-            "completion_status": self.lesson_status,
+            "completion_status": self.get_completion_status(),
             "grade": self.get_grade(),
-            "can_view_student_reports": self.can_view_student_reports,
             "scorm_xblock": self,
         }
         student_context.update(context or {})
         template = self.render_template("static/html/scormxblock.html", student_context)
         frag = Fragment(template)
         frag.add_css(self.resource_string("static/css/scormxblock.css"))
-        frag.add_javascript(self.resource_string("static/js/src/scorm.js"))
         frag.add_javascript(self.resource_string("static/js/src/scormxblock.js"))
-        frag.add_javascript(self.resource_string("static/js/vendor/renderjson.js"))
         frag.initialize_js(
             "ScormXBlock",
             json_args={
                 "scorm_version": self.scorm_version,
                 "fullscreen_on_launch": self.fullscreen_on_launch,
-                "popup_on_launch": self.popup_on_launch,
-                "popup_width": self.width or 800,
-                "popup_height": self.height or 800,
-                "scorm_data": self.scorm_data,
             },
         )
         return frag
@@ -213,7 +175,6 @@ class ScormXBlock(XBlock, CompletableXBlockMixin):
             "field_width": self.fields["width"],
             "field_height": self.fields["height"],
             "field_fullscreen_on_launch": self.fields["fullscreen_on_launch"],
-            "field_popup_on_launch": self.fields["popup_on_launch"],
             "scorm_xblock": self,
         }
         studio_context.update(context or {})
@@ -238,7 +199,6 @@ class ScormXBlock(XBlock, CompletableXBlockMixin):
         self.has_score = request.params["has_score"] == "1"
         self.weight = parse_float(request.params["weight"], 1)
         self.fullscreen_on_launch = request.params["fullscreen_on_launch"] == "1"
-        self.popup_on_launch = request.params["popup_on_launch"] == "1"
         self.icon_class = "problem" if self.has_score else "video"
 
         response = {"result": "success", "errors": []}
@@ -261,21 +221,6 @@ class ScormXBlock(XBlock, CompletableXBlockMixin):
 
         return self.json_response(response)
 
-    @XBlock.handler
-    def popup_window(self, request, _suffix):
-        """
-        Standalone popup window
-        """
-        rendered = self.render_template(
-            "static/html/popup.html",
-            {
-                "index_page_url": self.index_page_url,
-                "width": self.width or 800,
-                "height": self.height or 800
-            },
-        )
-        return Response(body=rendered)
-
     def clean_storage(self):
         if self.storage.exists(self.extract_folder_base_path):
             logger.info(
@@ -361,9 +306,6 @@ class ScormXBlock(XBlock, CompletableXBlockMixin):
 
     @XBlock.json_handler
     def scorm_get_value(self, data, _suffix):
-        """
-        Here we get only the get_value events that were not filtered by the LMSGetValue js function.
-        """
         name = data.get("name")
         if name in ["cmi.core.lesson_status", "cmi.completion_status"]:
             return {"value": self.lesson_status}
@@ -373,58 +315,42 @@ class ScormXBlock(XBlock, CompletableXBlockMixin):
             return {"value": self.lesson_score * 100}
         return {"value": self.scorm_data.get(name, "")}
 
-    @XBlock.json_handler
-    def scorm_set_values(self, data_list, _suffix):
-        return [self.set_value(data) for data in data_list]
-
     @XBlock.json_handler
     def scorm_set_value(self, data, _suffix):
-        try:
-            return self.set_value(data)
-        except ValueError as e:
-            return JsonHandlerError(400, e.args[0]).get_response()
-
-    def set_value(self, data):
-        name = data.get("name")
-        value = data.get("value")
-        completion_percent = None
-        success_status = None
-        completion_status = None
-        lesson_score = None
-
-        self.scorm_data[name] = value
-        if name == "cmi.core.lesson_status":
-            lesson_status = data.get("value")
-            if lesson_status in ["passed", "failed"]:
-                success_status = lesson_status
-            elif lesson_status in ["completed", "incomplete"]:
-                completion_status = lesson_status
-        elif name == "cmi.success_status":
-            success_status = value
-        elif name == "cmi.completion_status":
-            completion_status = value
-        elif name in ["cmi.core.score.raw", "cmi.score.raw"] and self.has_score:
-            lesson_score = parse_validate_positive_float(value, name) / 100.0
-        elif name == "cmi.progress_measure":
-            completion_percent = parse_validate_positive_float(value, name)
-
         context = {"result": "success"}
-        if lesson_score is not None:
-            self.lesson_score = lesson_score
-            context.update({"grade": self.get_grade()})
+        name = data.get("name")
+        publish_grade = False
+        completion_percent = None
+
+        if name in ["cmi.core.lesson_status", "cmi.completion_status"]:
+            self.lesson_status = data.get("value")
+            if data.get("value") in [
+                "completed",
+                "failed",
+                "passed",
+            ]:
+                completion_percent = 1
+                if self.has_score:
+                    publish_grade = True
+        elif name == "cmi.success_status":
+            self.success_status = data.get("value")
+            if self.has_score:
+                if self.success_status == "unknown":
+                    self.lesson_score = 0
+                publish_grade = True
+        elif name in ["cmi.core.score.raw", "cmi.score.raw"] and self.has_score:
+            self.lesson_score = float(data.get("value", 0)) / 100.0
+            publish_grade = True
+        else:
+            self.scorm_data[name] = data.get("value", "")
+
         if completion_percent is not None:
             self.emit_completion(completion_percent)
-        if completion_status:
-            self.lesson_status = completion_status
-            context.update({"completion_status": completion_status})
-        if success_status:
-            self.success_status = success_status
-        if completion_status == "completed":
-            self.emit_completion(1)
-        if success_status or completion_status == "completed":
-            if self.has_score:
-                self.publish_grade()
+        if publish_grade:
+            self.publish_grade()
+            context.update({"lesson_score": self.lesson_score})
 
+        context.update({"completion_status": self.get_completion_status()})
         return context
 
     def publish_grade(self):
@@ -435,21 +361,19 @@ class ScormXBlock(XBlock, CompletableXBlockMixin):
         )
 
     def get_grade(self):
-        lesson_score = 0 if self.is_failed else self.lesson_score
+        lesson_score = self.lesson_score
+        if self.lesson_status == "failed" or (
+            self.scorm_version == "SCORM_2004"
+            and self.success_status in ["failed", "unknown"]
+        ):
+            lesson_score = 0
         return lesson_score * self.weight
 
-    @property
-    def is_failed(self):
-        return self.success_status == "failed"
-
     def set_score(self, score):
         """
         Utility method used to rescore a problem.
         """
-        if self.has_score:
-            self.lesson_score = score.raw_earned
-            self.publish_grade()
-            self.emit_completion(1)
+        self.lesson_score = score.raw_earned / self.weight
 
     def max_score(self):
         """
@@ -481,13 +405,14 @@ class ScormXBlock(XBlock, CompletableXBlockMixin):
                 break
         root = tree.getroot()
 
-        prefix = "{" + namespace + "}" if namespace else ""
-        resource = root.find(
-            "{prefix}resources/{prefix}resource[@href]".format(prefix=prefix)
-        )
-        schemaversion = root.find(
-            "{prefix}metadata/{prefix}schemaversion".format(prefix=prefix)
-        )
+        if namespace is not None:
+            resource = root.find("{{{0}}}resources/{{{0}}}resource".format(namespace))
+            schemaversion = root.find(
+                "{{{0}}}metadata/{{{0}}}schemaversion".format(namespace)
+            )
+        else:
+            resource = root.find("resources/resource")
+            schemaversion = root.find("metadata/schemaversion")
 
         if resource is not None:
             self.index_page_path = resource.get("href")
@@ -529,6 +454,12 @@ class ScormXBlock(XBlock, CompletableXBlockMixin):
                 return path
         return None
 
+    def get_completion_status(self):
+        completion_status = self.lesson_status
+        if self.scorm_version == "SCORM_2004" and self.success_status != "unknown":
+            completion_status = self.success_status
+        return completion_status
+
     def scorm_location(self):
         """
         Unzipped files will be stored in a media folder with this name, and thus
@@ -567,81 +498,6 @@ class ScormXBlock(XBlock, CompletableXBlockMixin):
             }
         return {}
 
-    @XBlock.handler
-    def scorm_search_students(self, data, _suffix):
-        """
-        Search enrolled students by username/email.
-        """
-        if not self.can_view_student_reports:
-            return Response(status=403)
-        query = data.params.get("id", "")
-        enrollments = (
-            CourseEnrollment.objects.filter(
-                is_active=True,
-                course=self.runtime.course_id,
-            )
-            .select_related("user")
-            .order_by("user__username")
-        )
-        if query:
-            enrollments = enrollments.filter(
-                Q(user__username__startswith=query) | Q(user__email__startswith=query)
-            )
-        # The format of each result is dictated by the autocomplete js library:
-        # https://github.com/dyve/jquery-autocomplete/blob/master/doc/jquery.autocomplete.txt
-        return self.json_response(
-            [
-                {
-                    "data": {"student_id": enrollment.user.id},
-                    "value": "{} ({})".format(
-                        enrollment.user.username, enrollment.user.email
-                    ),
-                }
-                for enrollment in enrollments[:20]
-            ]
-        )
-
-    @XBlock.handler
-    def scorm_get_student_state(self, data, _suffix):
-        if not self.can_view_student_reports:
-            return Response(status=403)
-        user_id = data.params.get("id")
-        try:
-            user_id = int(user_id)
-        except (TypeError, ValueError):
-            return Response(
-                body="Invalid 'id' parameter {}".format(user_id), status=400
-            )
-        try:
-            module = StudentModule.objects.filter(
-                course_id=self.runtime.course_id,
-                module_state_key=self.scope_ids.usage_id,
-                student__id=user_id,
-            ).get()
-        except StudentModule.DoesNotExist:
-            return Response(
-                body="No data found for student id={}".format(user_id),
-                status=404,
-            )
-        except StudentModule.MultipleObjectsReturned:
-            logger.error(
-                "Multiple StudentModule objects found for Scorm xblock: "
-                "course_id=%s module_state_key=%s student__id=%s",
-                self.runtime.course_id,
-                self.scope_ids.usage_id,
-                user_id,
-            )
-            raise
-        module_state = json.loads(module.state)
-        scorm_data = module_state.get("scorm_data", {})
-        return self.json_response(scorm_data)
-
-    @property
-    def can_view_student_reports(self):
-        if StudentModule is None:
-            return False
-        return getattr(self.runtime, "user_is_staff", False)
-
     @staticmethod
     def workbench_scenarios():
         """A canned scenario for display in the workbench."""
@@ -697,17 +553,5 @@ def parse_float(value, default):
         return default
 
 
-def parse_validate_positive_float(value, name):
-    try:
-        parsed = float(value)
-    except (TypeError, ValueError):
-        raise ValueError(
-            "Could not parse value of '{}' (must be float): {}".format(name, value)
-        )
-    if parsed < 0:
-        raise ValueError("Value of '{}' must not be negative: {}".format(name, value))
-    return parsed
-
-
 class ScormError(Exception):
     pass
